# Orca
#
# Copyright 2020 Raspberry Pi (Trading) Ltd.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.

"""Custom script for lxpanel."""

__id__        = "$Id$"
__version__   = "$Revision$"
__date__      = "$Date$"
__copyright__ = "Copyright (c) 2020 Raspberry Pi (Trading) Ltd."
__license__   = "LGPL"

import pyatspi

import orca.debug as debug
import orca.orca as orca
import orca.orca_state as orca_state
import orca.scripts.toolkits.gtk as gtk

class Script(gtk.Script):

    def __init__(self, app):
        """Creates a new script for the given application."""

        gtk.Script.__init__(self, app)

    def onWindowDeactivated(self, event):
        """Called whenever a toplevel window is deactivated.

        Arguments:
        - event: the Event
        """
        if self.utilities.inMenu():
                if event.source.getState().contains (pyatspi.STATE_ACTIVE):
                        msg = "LXPANEL: Ignoring event. In menu."
                        debug.println(debug.LEVEL_INFO, msg, True)
                        return
                else:
                        msg = "LXPANEL: In menu but not active; continue deactivate."
                        debug.println(debug.LEVEL_INFO, msg, True)

        if event.source != orca_state.activeWindow:
            msg = "LXPANEL: Ignoring event. Not for active window."
            debug.println(debug.LEVEL_INFO, msg, True)
            return

        self.presentationInterrupt()
        self.clearBraille()

        if self.flatReviewContext:
            self.flatReviewContext = None

        self.pointOfReference = {}

        if not self.utilities.eventIsUserTriggered(event):
            msg = "LXPANEL: Not clearing state. Event is not user triggered."
            debug.println(debug.LEVEL_INFO, msg, True)
            return

        msg = "LXPANEL: Clearing state."
        debug.println(debug.LEVEL_INFO, msg, True)

        orca.setLocusOfFocus(event, None)
        orca_state.activeWindow = None
        orca_state.activeScript = None
        orca_state.listNotificationsModeEnabled = False
        orca_state.learnModeEnabled = False
